@@ -180,7 +180,7 @@ class Salesforce(SalureConnect):
         response = requests.get(url, headers=self.__get_headers())
         return response
 
-    def query_table(self, data_dir: str, table: str, fields: str, filter: str = '*', filename: str = None) -> pd.DataFrame:
+    def query_table(self, data_dir: str, table: str, fields: Union[str, List], filter: str = None, filename: str = None) -> pd.DataFrame:
         """
         for information about the tables, see: https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_query.htm
         With this method, you give a certain table you want to retrieve data from. This function contains a list of tables that are available in this function.
@@ -239,27 +239,17 @@ class Salesforce(SalureConnect):
         load_type = approved_tables[table]
         initial_load = False if os.path.exists(f'{data_dir}/cache/{filename}.ftr') else True
 
-        # If it is the initial load but in the future we want to do incremental loads and there is no filter, Add the fields ID, CreatedDate and LastModifiedDate to the fields
-        if initial_load and load_type == 'incremental' and filter == '*':
-            params = {"q": f"SELECT+{fields},Id,CreatedDate,LastModifiedDate+FROM+{table}"}
-        # If it is the initial load but in the future we want to do incremental loads and there is a filter, Add the fields ID, CreatedDate and LastModifiedDate to the fields and also apply the filter for the initial load
-        elif initial_load and load_type == 'incremental' and filter != '*':
-            params = {"q": f"SELECT+{fields},Id,CreatedDate,LastModifiedDate+FROM+{table}+WHERE+{filter}"}
-        # If it is the initial load and in the future we want the full load also, don't add the fields CreatedDate and LastModifiedDate because most of the times, they are not available for full load tables
-        elif initial_load and load_type == 'full':
-            params = {"q": f"SELECT+{fields},Id+FROM+{table}"}
+        fields = fields.split(',') if isinstance(fields, str) else fields
+        # Add metadata fields to the fields, then use set to avoid duplicates
+        fields.extend(['Id', 'CreatedDate', 'LastModifiedDate']) if load_type == 'incremental' else fields.extend(['Id'])
+        fields = ','.join(list(set(fields)))
+
         # If it's an incremental load with a filter, load the records that are created or updated in the last 14 days (double records will be removed later) and apply the filter
-        elif initial_load is False and load_type == 'incremental' and filter != '*':
-            params = {"q": f"SELECT+{fields},Id,CreatedDate,LastModifiedDate+FROM+{table}+WHERE+LastModifiedDate+>=+LAST_N_DAYS:14+AND+{filter}"}
-        # If it's an incremental load without a filter, load the records that are created or updated in the last 14 days (double records will be removed later)
-        elif initial_load is False and load_type == 'incremental' and filter == '*':
-            params = {"q": f"SELECT+{fields},Id,CreatedDate,LastModifiedDate+FROM+{table}+WHERE+LastModifiedDate+>=+LAST_N_DAYS:14"}
-        # If it's a full load with a filter, apply the filter
-        elif initial_load is False and load_type == 'full' and filter != '*':
-            params = {"q": f"SELECT+{fields},Id+FROM+{table}+WHERE+{filter}"}
+        if initial_load is False and load_type == 'incremental':
+            params = {"q": f"SELECT {fields} FROM {table} WHERE LastModifiedDate >= LAST_N_DAYS:7 {'' if filter is None or filter == '*' else ' AND ' + filter }"}
         # In all other cases, just load the full dataset without any filter and any field which is needed for incremental loads
         else:
-            params = {"q": f"SELECT+{fields},Id+FROM+{table}"}
+            params = {"q": f"SELECT {fields} FROM {table} {'' if filter is None or filter == '*' else ' WHERE ' + filter }"}
 
         params_str = urllib.parse.urlencode(params, safe=':+')
         url = f'{self.customer_url}/services/data/v{self.api_version}/query/?'
@@ -267,14 +257,14 @@ class Salesforce(SalureConnect):
         df = pd.DataFrame()
 
         # With the created URL and parameters, call the API
-        while done is False:
+        while not done:
             response = requests.get(url=url, params=params_str, headers=self.__get_headers())
             response.raise_for_status()
             done = response.json()['done']
             df_temp = pd.DataFrame(response.json()['records'])
             if 'attributes' in df_temp.columns:
                 del df_temp['attributes']
-            if done is False:
+            if not done:
                 url = f"{self.customer_url}{response.json()['nextRecordsUrl']}"
             df = pd.concat([df_temp, df])
 
